/**********************************************************************
* File: F28335_example.h
* Device: TMS320F28335
* Author: David M. Alter, Texas Instruments Inc.
* Description: Include file for example project.  Include this file in
*   all C-source files.
* Notes:
*   1) The following constants may be defined in the CCS project build
*      options:
*        EXAMPLE_NONBIOS
*        EXAMPLE_BIOS5
*        EXAMPLE_FLASH
*        EXAMPLE_RAM
* History:
*   03/15/08 - Added prototype for InitXintf() (D. Alter)
*   12/13/07 - original (D. Alter)
**********************************************************************/

#ifndef F28335_EXAMPLE_H
#define F28335_EXAMPLE_H


//---------------------------------------------------------------------------
// Constant Definitions
//
#define ADC_BUF_LEN			50				// ADC buffer length
#define ADC_SAMPLE_PERIOD	2999			// 2999 = 50 KHz sampling w/ 150 MHz SYSCLKOUT
#define PWM_HALF_PERIOD		37500			// period/2 for 2 kHz symmetric PWM
#define PWM_DUTY_CYCLE		28125			// 25% duty cycle


//---------------------------------------------------------------------------
// Include Standard C Language Header Files
//
#include <string.h>


//---------------------------------------------------------------------------
// Include any other Header Files
//
#include "DSP2833x_Device.h"				// Peripheral address definitions
#include "DSP2833x_DefaultIsr.h"		// ISR definitions


//---------------------------------------------------------------------------
// Function Prototypes
//
extern void DelayUs(Uint16);
extern void I2cInit(void);
extern void I2cTx(void);
extern void I2cWait(void);
extern void InitGpio(void);
extern void InitPieCtrl(void);
extern void InitSysCtrl(void);
extern void InitWatchdog(void);
extern void SetDBGIER(Uint16);


//---------------------------------------------------------------------------
// Global Variable References
//
extern Uint16 AdcBuf[ADC_BUF_LEN];			// ADC data buffer allocation
extern Uint32 PwmDuty;						// Measured PWM duty cycle
extern Uint32 PwmPeriod;					// Measured PWM period

extern const struct PIE_VECT_TABLE PieVectTableInit;	// Pie vector table (non-BIOS only)


//---------------------------------------------------------------------------
// Macros
//
#define ADC_cal_func_ptr (void (*)(void))0x380080


//---------------------------------------------------------------------------
#endif  // end of F28335_EXAMPLE_H definition


//--- end of file -----------------------------------------------------
